"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stream = require("stream");
const node_xz = require("../build/Release/node_xz.node");
const MIN_BUFSIZE = 1024;
const MAX_BUFSIZE = 64 * 1024;
exports.ENCODE_FINISH = node_xz.ENCODE_FINISH;
class XzStream extends stream.Transform {
    constructor(mode, options) {
        super(options);
        this.engine = new node_xz.Engine(mode, options ? options.preset : undefined);
        this.buffer = Buffer.alloc(options && options.bufferSize ? options.bufferSize : MIN_BUFSIZE);
    }
    _transform(chunk, encoding, callback) {
        const rv = this.process(chunk instanceof Buffer ? chunk : Buffer.from(chunk, encoding));
        this.push(rv);
        callback(undefined);
    }
    _flush(callback) {
        const rv = this.process(undefined, node_xz.ENCODE_FINISH);
        this.push(rv);
        callback(undefined);
    }
    process(input, flags) {
        // slightly too clever: we use the same buffer each time, as long as it's
        // big enough: the `concat` at the end will create a new one. if we need
        // to go back for a 2nd+ time, we replace it, since the array of `slice`
        // are just views.
        const bufSize = Math.max(Math.min(input ? input.length * 1.1 : this.buffer.length, MAX_BUFSIZE), MIN_BUFSIZE);
        if (bufSize > this.buffer.length)
            this.buffer = Buffer.alloc(bufSize);
        let n = this.engine.process(input, this.buffer, flags);
        let size = Math.abs(n);
        const segments = [this.buffer.slice(0, size)];
        while (n < 0) {
            this.buffer = Buffer.alloc(this.buffer.length);
            n = this.engine.process(undefined, this.buffer, flags);
            size += Math.abs(n);
            segments.push(this.buffer.slice(0, Math.abs(n)));
        }
        return Buffer.concat(segments, size);
    }
}
class Compressor extends XzStream {
    constructor(options) {
        super(node_xz.MODE_ENCODE, options);
    }
}
exports.Compressor = Compressor;
class Decompressor extends XzStream {
    constructor(options) {
        super(node_xz.MODE_DECODE, options);
    }
}
exports.Decompressor = Decompressor;
function compressRaw(preset) {
    return new node_xz.Engine(node_xz.MODE_ENCODE, preset);
}
exports.compressRaw = compressRaw;
function decompressRaw() {
    return new node_xz.Engine(node_xz.MODE_DECODE);
}
exports.decompressRaw = decompressRaw;
//# sourceMappingURL=xz.js.map